__author__ = 'feeir'
ERROR_TYPE_CLIENT = 'Client'
ERROR_TYPE_SERVER = 'Server'
ERROR_TYPE_THROTTLING = 'Throttling'
ERROR_TYPE_UNKNOWN = 'Unknown'

class ServerException(Exception):
    """
    server exception
    """

    def __init__(self, code, msg, http_status=None, request_id=None):
        Exception.__init__(self)
        self.error_code = code
        self.message = msg
        self.__error_type = ERROR_TYPE_SERVER
        self.http_status = http_status
        self.request_id = request_id

    def __str__(self):
        return "HTTP Status: %s Error:%s %s RequestID: %s" % (
            str(self.http_status),
            self.error_code,
            self.message,
            self.request_id
        )

    def set_error_code(self, code):
        self.error_code = code

    def set_error_msg(self, msg):
        self.message = msg

    def get_error_type(self):
        return self.__error_type

    def get_error_code(self):
        return self.error_code

    def get_error_msg(self):
        return self.message

    def get_http_status(self):
        return self.http_status

    def get_request_id(self):
        return self.request_id



class ClientException(Exception):
    """client exception"""

    def __init__(self, code, msg):
        """

        :param code: error code
        :param message: error message
        :return:
        """
        Exception.__init__(self)
        self.__error_type = ERROR_TYPE_CLIENT
        self.message = msg
        self.error_code = code

    def __str__(self):
        return "%s %s" % (
            self.error_code,
            self.message,
        )

    def set_error_code(self, code):
        self.error_code = code

    def set_error_msg(self, msg):
        self.message = msg

    def get_error_type(self):
        return self.__error_type

    def get_error_code(self):
        return self.error_code

    def get_error_msg(self):
        return self.message


__author__ = 'feeir'

import requests
import time
from hcrmsdkcore.exception.exceptions import ServerException, ClientException
from hcrmsdkcore.Sign.Sign import Sign

class HcrmCoreClient(object):

    def __init__(self, accesskey, secretykey):
        self.accesskey = accesskey
        self.secretykey = secretykey
        self.endpoint = 'https://hcrm.tal-ops.com/api/OpenApi/General/'
        self.get_timestamp()

    def get_timestamp(self):
        '''
        时间戳 timestamp 有效时效2小时
        :param :
        :return:
        '''
        self.timestamp = int(time.time())

    def do_action(self, request_path, params, method):
        '''
        请求函数
        :param method: 请求方法
        :param request_path: 请求路径
        :param params: 请求参数
        :return:  code: 0为成功 state: Success为请求成功 data: 数据
        '''
        sign_obj = Sign(self.accesskey, self.secretykey)
        sign = sign_obj.make(request_path, params, method)
        params.update({'sign': sign})
        print('params:', params)
        try:
            if method.upper() == 'GET':
                rsp = requests.get('{endpoint}{request_path}'.format(
                    endpoint=self.endpoint, request_path=request_path), params=params)
            else:
                rsp = requests.post('{endpoint}{request_path}'.format(
                    endpoint=self.endpoint, request_path=request_path), data=params)
        except Exception as e:
            raise ClientException('doRequest', e)
        if not rsp.ok:
            raise ServerException(
                rsp.status_code,
                rsp.content
            )
        try:
            request_data = rsp.json()
        except Exception as e:
            raise ClientException('Json decoding', e)
        return request_data



__author__ = 'feeir'

import binascii
import hashlib
import hmac

class Sign(object):
    def __init__(self, accesskey, secretykey):
        self.accesskey = accesskey
        self.secretykey = bytes(secretykey, 'utf-8')

    def make(self, request_path, params, method='GET'):
        srcStr = method.upper() + request_path + '?' + "&".join(
            k.replace("_", ".") + "=" + str(params[k]) for k in sorted(params.keys()))
        print(srcStr)
        srcStr = bytes(srcStr, 'utf-8')
        hashed = hmac.new(self.secretykey, srcStr, hashlib.sha1)
        return str(binascii.b2a_base64(hashed.digest())[:-1], encoding='utf-8')


__author__ = 'feeir'

import requests
import time
from hcrmsdkcore.Client.Client import HcrmCoreClient

class HcrmGeneralRequest(HcrmCoreClient):

    def __init__(self, accesskey, secretykey):
        super().__init__(accesskey, secretykey)


    def general(self, action, page_number=1, method='GET', request_path='/api/OpenApi/General/'):
        '''
        :param action: 请求动作
        :param page_number: 页码 默认1
        :param method: 请求方法
        :param request_path: 请求路径
        :return:
        '''
        params = {'accesskey': self.accesskey, 'timestamp': self.timestamp, 'action': action, 'page_number': page_number}
        rsp = self.do_action(request_path, params, method)
        print(rsp)
        return rsp

if __name__ == '__main__':
    accesskey = 'hcrm-enCQH6DucEwfcNT8'
    secretykey = 't5geRZ1U7nCfBiqz5cLYCC2NsUWjAiSH'
    hcrm_cls = HcrmGeneralRequest(accesskey, secretykey)
    # 获取公有云服务器资源列表
    #hcrm_cls.general('cloud_server_instance', method='GET')
    # 获取私有云服务器资源列表
    #hcrm_cls.general('private_cloud_server_instance', method='GET')
    # 获取MySql资源列表
    hcrm_cls.general('mysql_instance', method='GET')





# -*- coding: utf8 -*-
from setuptools import setup, find_packages
from hcrmsdkcore import __version__
setup(
      name='hcrm-sdk-core',   #名称
      version=__version__,  #版本
      description="tal hcrm python3 sdk", #描述
      keywords='python english translation dictionary terminal',
      author='tianpengfei',  #作者
      author_email='54587841@qq.com', #作者邮箱
      url='https://github.com/feeir', #作者链接
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires=[      #需求的第三方模块
        'requests',
      ],
      entry_points={
        'console_scripts':[     #如果你想要以Linux命令的形式使用
            'bword = bword.bword:main'
        ]
      },
)